#
# spec file for package mate-session-manager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mate-session-manager
Version:        1.28.0
Release:        1.1
Summary:        MATE Session Manager
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# Not an upstream file. Only proposes upstream packages:
Source1:        mate-session-manager-upstream-mate_defaults.conf
# Some documentation for people writing branding packages, shipped in the branding-upstream package.
Source2:        README.Gsettings-overrides
# xinitrc.d/ script that add /usr/share/mate and /usr/local/share to XDG_DATA_DIRS
Source3:        55mate-session_materc.sh
# xinitrc.d/ script that finalizes everything before the MATE session starts (such as
# preparing to load the canberra-gtk-module and applying a clutter tweak).
Source4:        99mate-environment.sh
# PATCH-FIX-OPENSUSE mate-session-manager-qt-5.7-styleoverride.patch sor.alexei@meowr.ru -- On Qt 5.7+ use Gtk2 Platform Theme.
Patch0:         mate-session-manager-qt-5.7-styleoverride.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xtrans)
Requires:       %{name}-branding >= %{_version}
Requires:       %{name}-gschemas >= %{version}
# Make native styling in Qt5 happen.
Requires:       libqt5-qtstyleplugins-platformtheme-gtk2
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
This package contains a session that can be started from a display
manager such as LightDM. It will load all necessary applications
for a full-featured user session.

%lang_package

%package branding-upstream
Summary:        Upstream definitions of default settings and applications
Requires:       %{name} = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: The /etc/mate_defaults.conf allows to define arbitrary
#BRAND: applications as preferred defaults.
#BRAND: A /usr/share/glib-2.0/schemas/$NAME.gschema.override file can
#BRAND: be used to override the default value for GSettings keys. See
#BRAND: README.Gsettings-overrides for more details. The branding
#BRAND: package should then have proper Requires for features changed
#BRAND: with such an override file.

%description -n mate-session-manager-branding-upstream
This package provides upstream defaults for settings stored with
GSettings and applications used by the MIME system.

%package gschemas
Summary:        MATE Session Manager GSchemas
%glib2_gsettings_schema_requires
BuildArch:      noarch

%description gschemas
This package provides the GSettings schemas for
MATE Session Manager.

%prep
%autosetup -p1

cp -a %{SOURCE2} .
cp -a %{SOURCE1} mate_defaults.conf
cp -a %{SOURCE3} .
cp -a %{SOURCE4} .

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static             \
  --enable-ipv6                \
  --with-default-wm=marco      \
  --enable-qt57-theme-support  \
  --with-systemd=yes
%make_build

%install
%make_install
install -Dpm 0644 mate_defaults.conf \
  %{buildroot}%{_sysconfdir}/mate_defaults.conf
install -Dpm 0755 55mate-session_materc.sh \
  %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/55mate-session_materc.sh
install -Dpm 0755 99mate-environment.sh \
  %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/99mate-environment.sh

mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop \
  %{buildroot}%{_datadir}/xsessions/default.desktop

%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file mate-session-properties
%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/mate.desktop

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/mate.desktop 20

%postun
if [ ! -f %{_datadir}/xsessions/mate.desktop ]; then
    %{_sbindir}/update-alternatives --remove default-xsession.desktop \
      %{_datadir}/xsessions/mate.desktop
fi

%files
%license COPYING
%doc NEWS README
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%dir %{_sysconfdir}/X11/xinit
%dir %{_sysconfdir}/X11/xinit/xinitrc.d
%config %{_sysconfdir}/X11/xinit/xinitrc.d/55mate-session_materc.sh
%config %{_sysconfdir}/X11/xinit/xinitrc.d/99mate-environment.sh
%{_bindir}/mate-*
%{_datadir}/%{name}/
%{_datadir}/xsessions/*.desktop
%{_datadir}/applications/mate-session-properties.desktop
%{_datadir}/icons/hicolor/*/apps/mate-session-properties.*
%{_mandir}/man?/mate-*.?%{?ext_man}
%{_libexecdir}/mate-*

%files lang -f %{name}.lang

%files branding-upstream
%doc README.Gsettings-overrides
%config(noreplace) %{_sysconfdir}/mate_defaults.conf

%files gschemas
%{_datadir}/glib-2.0/schemas/*.xml

%changelog
* Tue Mar 26 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translations update
  * Revert "gsm-manager: use g_settings_schema_source_lookup ()"
  * Add system desktop files item to automatic startup support
  * main: fix double free on gl_renderer
  * g_key_file_save_to_file () is available from glib 2.40
  * gsm-manager: use g_settings_schema_source_lookup ()
  * gsm-inhibit-dialog: Fix -Wimplicit-int-float-conversion warnings
  * Fix build warnings about missing field initializer
  * Fix implicit conversion changes signedness: 'gboolean' to 'guint'
  * mate-session: fix memory leak
  * configure.ac: The macro 'AC_HELP_STRING' is obsolete
* Tue Jun 20 2023 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- 99mate-environment.sh: Assure that this file gets sourced during
  xinit-based startup.
- 99mate-environment.sh: Set CLUTTER_BACKEND to "x11,*" instead of just "x11".
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * Fix memory leaks.
  * Update translations.
* Thu Jun 30 2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- Provide xinitrc.d script 55mate-session_materc.sh, adopted from
  Debian/Ubuntu. This provides support for MATE-specific tweaking of the
  Application menu such as practiced in Ubuntu MATE intensively.
- Provide xinitrc.d script 99mate-environment.sh, adopted from Debian/Ubuntu.
  This script allows us to finalize MATE session startup. Here we e.g.
  prepare loading the canberra GTK module and tweak UI stuff. There
  are likely more things to come.
* Thu Aug 12 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * Update copyright to 2021
  * Follow freedesktop guidelines to disable autorun using Hidden key
  * Capplet: use a function to set the visibility of treeview rows
  * Look for the location of the locking screen app using user's PATH
  * Capplet: memory leak
  * Fix building Serbian translation
  * mate-session-check-accelerated-common: missing include guard
  * Capplet: i18n parameter_string argument of gtk_init_with_args
  * Build: allow users to disable gettext support (--disable-nls)
  * Build: set GETTEXT_PACKAGE=AC_PACKAGE_NAME
  * Support xscreensaver when mate-screensaver is not available
  * Remove warning -Wshadow
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.3:
  * Translations update
  * Follow freedesktop guidelines to disable autorun using Hidden key
  * capplet: use a function to set the visibility of treeview rows
  * Look for the location of the locking screen app using user's PATH
  * capplet: memory leak
  * Support xscreensaver when mate-screensaver is not available
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * Using #include with system libraries.
  * build: Silent build warnings for distcheck.
  * Accept Desktop Entry Specification v1.1.
  * use default MATE_COMPILE_WARNINGS for stable branch.
  * build: Make libglesv2 optional.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * build: Show warning flags on configure summary.
  * Avoid redundant redeclarations.
  * desktop files: Add translator hints.
  * Fix timeout with gnome-keyring 3.34.
  * Remove GNOME_KEYRING_LIFETIME_FD.
  * po/Makevars: Set COPYRIGHT_HOLDER to The MATE Team.
  * Fix mate-session-properties vertical scaling.
  * Update translations.
- Drop support for old openSUSE versions.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Update translations
  * migrate from intltool to gettext
  * test-inhibit.c: migrate to gdbus
  * Don't add apps repeatedly
  * Add Show hidden checkbox and gsettings flag.
  * Hide NoDisplay Apps in Startup Applications
  * Simplify the installation process of the icons
  * main: Potential leak of memory pointed to by 'new_argv'
  * [Security] Use 'g_strlcpy' instead of 'strcpy'
  * Add missing CPPFLAGS for mate_session_check_accelerated helpers
  * Add hardware-compatibility file
  * Fix unable to retrieve org.gnome.SessionManager.Renderer property
  * mate-session-check-accelerated-gles-helper
  * Add mate_session_check_accelerated helpers
  * add installation instructions and update URL
- remove patches:
  * mate-session-manager-gtk-3.20.patch: we don't support gtk3.20
    anymore
- require gtk >= 3.22, glib >= 2.50 and gio >= 2.50
- ship mate-session-check-accelerated tools and build require there
  for glesv2
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Add installation instructions and update URL.
  * Remove duplicate check for libelogind.
  * Add elogind support.
  * Guard against missing systemd.
  * Update translations.
- Rebase mate-session-manager-qt-5.7-styleoverride.patch.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Avoid deprecated GtkStock.
  * manager: Restart user bus if last graphical session.
  * systemd: Add api for detecting if this is the last session for
    a user.
  * gsm: Disconnect all dbus clients when dbus is disconnected.
  * manager: Don't wait for all clients to exit before exiting.
  * [gsm-autostart-app] Migrate from dbus-glib to gdbus.
  * gsm-app-dialog: Make the seconds translatables in the
    spinbutton.
  * Change application startup dalay where it is in the system path.
  * Remove X-GNOME-Autostart-Delay support.
  * Add a delay setting to Startup Manager.
  * Avoid gtk_dialog_add_button with stock ids.
  * mate-session-save: Show icon in error dialogue.
  * Migrate from dbus-glib to gdbus.
  * gsm-inhibit-dialog.ui: Avoid deprecated GtkVBox.
  * session-properties.ui: Avoid deprecations.
  * gsm-manager: Avoid deprecated g_settings_list_schemas.
  * Avoid compile warning for g_type_class_add_private.
  * Only show application name when run with --version.
  * Strip outer single quotes from string value returned by
    gsettings in mate-wm script.
  * Replace deprecated gdk_error_trap functions.
  * Update translations.
- Rebase mate-session-manager-gtk-3.20.patch.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Disable deprecation warnings for distcheck.
  * Fix a typo in --logout-dialog option.
  * Update translations.
* Sun Jun 17 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Fix a broken link in man pages.
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Avoid deprecated gdk_screen_get_number(),
    gdk_screen_make_display_name() functions.
  * Don't use deprecated gtk_show_uri().
  * gsm-manager.c: Fix a build warning.
  * Update translations.
- Add mate-session-manager-gtk-3.20.patch: Restore GLib 2.48 and
  GTK+ 3.20 support.
* Fri Oct 27 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Don't lose focus when displaying a logout or shutdown dialogue.
  * Add a style class logout-dialog.
  * Update translations.
* Sat Jul 22 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * systemd user-session needs to be updated to get the whole
    user-defined enviroment when the session starts.
  * dbus needs to be updated to get the whole user-defined
    environment when the session starts.
  * Update translations.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Use update-alternatives to create the default.desktop xsession
  (boo#1046352).
* Sat Apr  1 2017 sor.alexei@meowr.ru
- Apply Qt 5.7+ stuff only for openSUSE newer than Leap 42.x
  (boo#1020334).
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Replace deprecated upower suspend/hibernate functions with
    ConsoleKit2 equivalents.
  * Update translations.
- Rebase mate-session-manager-qt-5.7-styleoverride.patch.
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Build: Check stricter for presence of xtrans (ensure that
    mate-session won't listen to TCP ports).
  * Session properties: Fix vertical expand of content with window
    resize.
  * Check for a gdm-binary process when switching the user.
* Wed Jan 18 2017 sor.alexei@meowr.ru
- Add the missing xtrans build dependency (boo#1020683).
* Mon Oct 24 2016 sor.alexei@meowr.ru
- Undo the previous change: boo#1006470 was handled in
  libqt5-qtstyleplugins.
* Mon Oct 24 2016 hillwood@opensuse.org
- Fix boo#1006470, use Recommends tag instead of Requires.
* Fri Oct 21 2016 sor.alexei@meowr.ru
- Add mate-session-manager-qt-5.7-styleoverride.patch: On Qt 5.7+
  use Gtk2 Platform Theme (party based on cinnamon-session changes
  made by Dustin Falgout).
- Require libqt5-qtstyleplugins-platformtheme-gtk2 to make sure the
  user actually gets native styling on Qt5.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Move to GTK+3 (require GTK+ >= 3.14), drop GTK+2 code and
  - -with-gtk build option.
  * Update translations.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * GTK+3: Fix critical warning in logout/shutdown dialogues.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Add Changelog generation.
* Tue Apr  5 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Drop MateConf migration script.
  * Gtk3: Fix some deprecations.
  * Some more fixes and cleanups.
  * Update translations.
- Switch to Gtk3.
* Tue Apr  5 2016 sor.alexei@meowr.ru
- Update to version 1.12.2:
  * Fix a rare build failure with UPower >= 0.99 when both systemd
    and UPower supports are enabled.
  * Some more fixes.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Separate gschemas into mate-session-manager-gschemas package.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Get rid of dependency on libmate-desktop.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Only wait 1 second max on logout/shutdown.
  * Some more fixes and cleanups.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Add support for a new libsystemd library.
  * Add support for an optional dock, such as Plank.
  * Use org.gnome.SessionManager at /org/gnome/SessionManager as
    the D-Bus API.
  * Add option to disable overlay scrolling.
* Mon Jul 13 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Reintroduce missing help in session properties dialog.
  * Set XDG_CURRENT_DESKTOP env var to MATE.
  * Some bugfixes.
  * Update translations.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Fix size of GtkScrolledWindow in session properties.
  * Check for running display manager when user switching.
- Spec cleanup.
* Wed Apr 15 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.90
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bugfixes release
- Remove mate-session-manager-check-for-X11-libraries.patch; merged
  on upstream release
* Sun Nov 23 2014 p.drouand@gmail.com
- Add pkgconfig(mate-desktop-2.0) build dependency; new build
  requirement
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.3 (unstable)
  + Update translations
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + Disable upower support by default (use --enable-upower if you
    need it)
- Remove "--disable-upower" coonfigure option; now the default
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + No changelog available
* Wed Jul 16 2014 p.drouand@gmail.com
- Add mate-session-manager-check-for-X11-libraries.patch
- Remove useless pkgconfig(pangox); mate-session-manager doesn't
  build against pangox
- Replace pkgconfig(systemd) with systemd-devel;  systemd development
  files are needed to build with systemd support
* Sat Mar 15 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Add autostart of accessibility apps
  + Fix build with upower disabled
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
- Do not require hicolor-icon-theme; it's wrong and unoptimized
- Remove fix-systemd-login1-support-for-hibernate-or-suspend.patch;
  fixed by upstream
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + show a progress bar in logout dialog
  + add GTK3 support
  + add gnome keyring support
  + add support for X-MATE-Autostart-Delay in desktop files
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.2 (unstable)
  + fix transifex configuration file
- Changes from version 1.7.1
  + fix makefile with automake-1.13
  + GTK3: Fix compile warning by using gdk_error_trap_pop_ignored()
  + GTK3: fix compile warning 'gtk_target_table_new_from_list' differ
    in signedness [-Wpointer-sign]
  + make upower optional
  + session: support_autostart_delay
- Changes from version 1.7.0
  + Initial GTK3 support
  + fix return value in void functions
  + fix g_type_init deprecation
  + systemd support: session_id is char*, not int
  + fix systemd-login1 support for hibernate/suspend
  + replace ghelp: with help: for user-guide
- Add systemd and remove upower build requirements
- Build with systemd and without upower support because of new
  upower API
- Build with pangox support
- Use marco as default window manager in ./configure
- Add --enable-ipv6 to configure options to get session-manager
  ipv6 capable
* Fri Sep 13 2013 p.drouand@gmail.com
-Add fix-systemd-login1-support-for-hibernate-or-suspend.patch;
  support hibernate or suspend when used with systemd
* Mon Apr 29 2013 p.drouand@gmail.com
- No version for "Recommends: %%{name}-lang"
* Fri Apr  5 2013 p.drouand@gmail.com
- Some typo fixes
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + no changelog available
* Thu Mar 28 2013 p.drouand@gmail.com
- Add a branding upstream subpackage
* Fri Mar 22 2013 nmo.marques@gmail.com
- Update to version 1.5.2:
  + increase phase timeout to 30 secs
  + remove wrong g_free in systemd code
  + add initial systemd support
* Sun Feb 10 2013 johann.luce@wanadoo.fr
- Update to version 1.5.1:
  + No changelog available
- remove %%{name}-1.5.0-fix_screensaver_gschema_usage.patch
  Merged and fixed on upstream release
* Mon Nov 26 2012 nmo.marques@gmail.com
- Add %%{name}-1.5.0-fix_screensaver_gschema_usage.patch; fix
  mate-session crash due to missing key in schema; also fixes
  the Suspend/Hibernate buttons not working (because mate-session
  crashed)
* Wed Oct 10 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + drop mateconf in favor of gsettings
- Remove mateconf-2.0 from BRs and macros; use gsettings
- Add hicolor-icon-theme dependencies and macros
* Sat Sep  8 2012 nmo.marques@gmail.com
- update to version 1.4.0
  + Add pkgconfig(xau) and pkgconfig(xext) to BRs
- copypac to X11:MATE
  + minor cosmetic fixes
* Sat Jun 16 2012 nmo.marques@gmail.com
- update to version 1.2.0
  + move spec to use mateconf macros and minor cleanups
* Wed Feb 22 2012 fisiu@opensuse.org
- initial package from version 1.2.0
